gamm_site.Rdmodels the growth trend or climate-growth relationship per site.
gamm_site(data, resp_scale = "resp_gamma", m.candidates)data containing all necessary columns to run the model
Character. Specifies how the response variable is treated in the model.
"resp_gaussian": Uses the response on its original scale, assuming a Gaussian distribution with an identity link (no transformation applied).
"resp_log": Log-transforms the response before modelling. The transformed response is then assumed to follow a Gaussian distribution with an identity link.
"resp_gamma": Keeps the response on its original scale, fitted under a Gamma distribution with a log link. Suitable for strictly positive and right-skewed data.
the list of candidate equations.
list including model, fitting statistics, ptable, stable and prediction table
This function accounts for within-site variability and temporal autocorrelation by including series identity as random effects and a first-order autoregressive (AR1) correlation structures, respectively. using mgcv::gamm()
If users specify multiple candidate models through the m.candidates argument, the function will fit each candidate model using the maximum likelihood (ML) method. The corrected Akaike Information Criterion (AICc) will then be compared to determine the best-fitting model. Once the optimal model is identified, it will be refitted using the restricted maximum likelihood (REML) method and output the results.
If users specify only 1 candidate model through the m.candidates argument, the model is fitted with "REML" method.
#' @examples
# loading processed data
dt.samples_trt <- readRDS(system.file("extdata", "dt.samples_trt.rds", package = "growthTrendR"))
# climate
dt.clim <- data.table::fread(system.file("extdata", "dt.clim.csv", package = "growthTrendR"))
# pre-data for model
dt.samples_clim <- prepare_samples_clim(dt.samples_trt, dt.clim)
dt.m <- dt.samples_clim[uid_site == 1][ageC >1]
# gamm_site model
m.site <-gamm_site(data = dt.m, resp_scale = "resp_log",
m.candidates = c(
"bai_cm2 ~ log(ba_cm2_t_1) + s(ageC) + s(FFD)",
"bai_cm2 ~ log(ba_cm2_t_1) + s(ageC) + FFD",
"bai_cm2 ~ log(ba_cm2_t_1) + s(ageC)"))