plot_freq.RdThis function plots the frequency distribution by geo-location for each species
plot_freq(dt.freq, out.species = "all")A list of ggplot objects corresponding to the species
requested via out.species. Each element of the list contains
a faceted spatial plot of tree locations, with point size proportional
to the number of samples.
# loading processed data
dt.samples_trt <- readRDS(system.file("extdata", "dt.samples_trt.rds", package = "growthTrendR"))
dt.freq <- CFS_freq(
dt.samples_trt$tr_all_wide,
freq.label_data = "demo-samples",
freq.uid_level = "uid_radius")
plots.lst <- plot_freq(dt.freq)