CFS_freq.Rdfrequency distributions by geo-location per species
CFS_freq(
data,
freq.label_data = "",
freq.uid_level = "uid_radius",
freq.cutoff_year = -999,
freq.geo_resolution = NULL
)meta table from function CFS_format()
description of data
which uid level to count(uid_project, uid_site, uid_tree, uid_meas, uid_sample, uid_radius)
cut-off year for a subset which series were recorded on or after
Numeric vector (lon, lat) giving spatial resolution in degrees (e.g., c(5, 3)). If NULL, each value defaults to one quarter of the corresponding coordinate range.
a data table of counts of uid by latitude-longitude per species
# treated ring measurement
dt.samples_trt <- readRDS(system.file("extdata", "dt.samples_trt.rds", package = "growthTrendR"))
# Compute frequency statistics at radius level
dt.freq <- CFS_freq(
dt.samples_trt$tr_all_wide,
freq.label_data = "demo-samples",
freq.uid_level = "uid_radius"
)
class(dt.freq)
#> [1] "cfs_freq"